@@ -8,7 +8,7 @@ if (typeof (django) !== 'undefined' && typeof (django.jQuery) !== 'undefined') {
       for (const checkbox of checkboxes) {
         if (checkbox.classList.contains('action-select')) {
           // Add aria-label to each table row checkbox, so that each option is able to be read by screen readers.
-          checkbox.setAttribute('aria-label', `Row ${checkbox.value}`)
+          checkbox.setAttribute('aria-label', checkbox.name || checkbox.value)
         } else if (checkbox.id === 'action-toggle') {
           // Similarly, add a label to the "toggle all" checkbox in the first row of the table.
           checkbox.setAttribute('aria-label', 'Toggle all')
